pub struct EventService { /* private fields */ }Expand description
Implements a client for the Cloud Talent Solution API.
Example
async fn sample(
) -> anyhow::Result<()> {
let client = EventService::builder().build().await?;
let response = client.create_client_event()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Service Description
A service handles client event report.
Configuration
To configure EventService use the with_* methods in the type returned
by builder(). The default configuration should
work for most applications. Common configuration changes include
- with_endpoint(): by default this client uses the global default endpoint
(
https://jobs.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured with Private Google Access with VPC Service Controls) may want to override this default. - with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.
Pooling and Cloning
EventService holds a connection pool internally, it is advised to
create one and reuse it. You do not need to wrap EventService in
an Rc or Arc to reuse it, because it
already uses an Arc internally.
Implementations
Sourceimpl EventService
impl EventService
Sourcepub fn builder() -> ClientBuilder
pub fn builder() -> ClientBuilder
Returns a builder for EventService.
let client = EventService::builder().build().await?;Sourcepub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: EventService + 'static,
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Selfwhere
T: EventService + 'static,
Creates a new client from the provided stub.
The most common case for calling this function is in tests mocking the client’s behavior.
Sourcepub fn create_client_event(&self) -> CreateClientEvent
pub fn create_client_event(&self) -> CreateClientEvent
Report events issued when end user interacts with customer’s application that uses Cloud Talent Solution. You may inspect the created events in self service tools. Learn more about self service tools.
Example
use google_cloud_talent_v4::Result;
async fn sample(
client: &EventService
) -> Result<()> {
let response = client.create_client_event()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Sourcepub fn get_operation(&self) -> GetOperation
pub fn get_operation(&self) -> GetOperation
Provides the Operations service functionality in this service.
Example
use google_cloud_talent_v4::Result;
async fn sample(
client: &EventService
) -> Result<()> {
let response = client.get_operation()
/* set fields */
.send().await?;
println!("response {:?}", response);
Ok(())
}Trait Implementations
Sourceimpl Clone for EventService
impl Clone for EventService
Sourcefn clone(&self) -> EventService
fn clone(&self) -> EventService
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreAuto Trait Implementations
impl !RefUnwindSafe for EventService
impl !UnwindSafe for EventService
impl Freeze for EventService
impl Send for EventService
impl Sync for EventService
impl Unpin for EventService
impl UnsafeUnpin for EventService