JobService

Struct JobService 

pub struct JobService { /* private fields */ }
Implements a client for the Cloud Talent Solution API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
async fn sample(
   project_id: &str,
   tenant_id: &str,
) -> anyhow::Result<()> {
    let client = JobService::builder().build().await?;
    let mut list = client.list_jobs()
        .set_parent(format!("projects/{project_id}/tenants/{tenant_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}

Service Description

A service handles job management, including job CRUD, enumeration and search.

Configuration

To configure JobService use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

Pooling and Cloning

JobService holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap JobService in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl JobService

pub fn builder() -> ClientBuilder

Returns a builder for JobService.

let client = JobService::builder().build().await?;
pub fn from_stub<T>(stub: impl Into<Arc<T>>) -> Self
where T: JobService + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn create_job(&self) -> CreateJob

Creates a new job.

Typically, the job becomes searchable within 10 seconds, but it may take up to 5 minutes.

Example
use google_cloud_talent_v4::model::Job;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService, project_id: &str, tenant_id: &str
) -> Result<()> {
    let response = client.create_job()
        .set_parent(format!("projects/{project_id}/tenants/{tenant_id}"))
        .set_job(
            Job::new()/* set fields */
        )
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn batch_create_jobs(&self) -> BatchCreateJobs

Begins executing a batch create jobs operation.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.batch_create_jobs()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_job(&self) -> GetJob

Retrieves the specified job, whose status is OPEN or recently EXPIRED within the last 90 days.

Example
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService, project_id: &str, tenant_id: &str, job_id: &str
) -> Result<()> {
    let response = client.get_job()
        .set_name(format!("projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}"))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_job(&self) -> UpdateJob

Updates specified job.

Typically, updated contents become visible in search results within 10 seconds, but it may take up to 5 minutes.

Example
use google_cloud_wkt::FieldMask;
use google_cloud_talent_v4::model::Job;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService, project_id: &str, tenant_id: &str, job_id: &str
) -> Result<()> {
    let response = client.update_job()
        .set_job(
            Job::new().set_name(format!("projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}"))/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn batch_update_jobs(&self) -> BatchUpdateJobs

Begins executing a batch update jobs operation.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.batch_update_jobs()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_job(&self) -> DeleteJob

Deletes the specified job.

Typically, the job becomes unsearchable within 10 seconds, but it may take up to 5 minutes.

Example
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService, project_id: &str, tenant_id: &str, job_id: &str
) -> Result<()> {
    client.delete_job()
        .set_name(format!("projects/{project_id}/tenants/{tenant_id}/jobs/{job_id}"))
        .send().await?;
    Ok(())
}
pub fn batch_delete_jobs(&self) -> BatchDeleteJobs

Begins executing a batch delete jobs operation.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.batch_delete_jobs()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_jobs(&self) -> ListJobs

Lists jobs by filter.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService, project_id: &str, tenant_id: &str
) -> Result<()> {
    let mut list = client.list_jobs()
        .set_parent(format!("projects/{project_id}/tenants/{tenant_id}"))
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn search_jobs(&self) -> SearchJobs

Searches for jobs using the provided SearchJobsRequest.

This call constrains the visibility of jobs present in the database, and only returns jobs that the caller has permission to search against.

Example
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.search_jobs()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn search_jobs_for_alert(&self) -> SearchJobsForAlert

Searches for jobs using the provided SearchJobsRequest.

This API call is intended for the use case of targeting passive job seekers (for example, job seekers who have signed up to receive email alerts about potential job opportunities), it has different algorithmic adjustments that are designed to specifically target passive job seekers.

This call constrains the visibility of jobs present in the database, and only returns jobs the caller has permission to search against.

Example
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.search_jobs_for_alert()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_talent_v4::Result;
async fn sample(
   client: &JobService
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}